@@ -41,7 +41,9 @@ parser.add_argument('--unmute',  action="store_true",  help='Show result of prin
 parser.add_argument('--passall',  action="store_true",  help='Automatically pass all tests. Useful when debugging.')
 parser.add_argument('--noprogress',  action="store_true",  help='Disable progress bars.')
 
-def evaluate_report_student(report, question=None, qitem=None, unmute=None, passall=None, ignore_missing_file=False, show_tol_err=False, show_privisional=True, noprogress=None):
+def evaluate_report_student(report, question=None, qitem=None, unmute=None, passall=None, ignore_missing_file=False,
+                            show_tol_err=False, show_privisional=True, noprogress=None,
+                            generate_artifacts=True):
     args = parser.parse_args()
     if noprogress is None:
         noprogress = args.noprogress
@@ -63,7 +65,8 @@ def evaluate_report_student(report, question=None, qitem=None, unmute=None, pass
 
     results, table_data = evaluate_report(report, question=question, show_progress_bar=not unmute and not noprogress, qitem=qitem,
                                           verbose=False, passall=passall, show_expected=args.showexpected, show_computed=args.showcomputed,unmute=unmute,
-                                          show_tol_err=show_tol_err)
+                                          show_tol_err=show_tol_err,
+                                          generate_artifacts=generate_artifacts)
 
 
     if question is None and show_privisional:
@@ -105,6 +108,7 @@ class SequentialTestLoader(unittest.TestLoader):
 def evaluate_report(report, question=None, qitem=None, passall=False, verbose=False,  show_expected=False, show_computed=False,unmute=False, show_help_flag=True, silent=False,
                     show_progress_bar=True,
                     show_tol_err=False,
+                    generate_artifacts=True, # Generate the artifact .json files. These are exclusively used by the dashboard.
                     big_header=True):
 
     from unitgrade.version import __version__
@@ -129,6 +133,7 @@ def evaluate_report(report, question=None, qitem=None, passall=False, verbose=Fa
     loader = SequentialTestLoader()
 
     for n, (q, w) in enumerate(report.questions):
+        q._generate_artifacts = generate_artifacts  # Set whether artifact .json files will be generated.
         if question is not None and n+1 != question:
             continue
         suite = loader.loadTestsFromTestCase(q)
@@ -173,8 +178,9 @@ def evaluate_report(report, question=None, qitem=None, passall=False, verbose=Fa
             else:
                 raise Exception("Status not known.")
 
-            nice_title = s.title
-            detail = {**detail, **msg, 'nice_title': nice_title}#['message'] = msg
+            # s can be an '_ErrorHolder' object, which has no title.
+            nice_title = s.title if hasattr(s, 'title') else 's has no title; unitgrade/evaluate.py line 181'
+            detail = {**detail, **msg, 'nice_title': nice_title} #['message'] = msg
             details[key] = detail
 
         # q_[s._testMethodName] = ("pass", None)
