@@ -540,15 +540,19 @@ class UTestCase(unittest.TestCase):
             return
         import importlib, inspect
         found_reports = []
-        # print("But do I have report", self._report)
-        # print("I think I am module", self.__module__)
-        # print("Importlib says", importlib.import_module(self.__module__))
+
+        good_module_name = self.__module__
+        try:
+            importlib.import_module(good_module_name)
+        except Exception as e:
+            good_module_name = os.path.basename(good_module_name)[:-3]
+
         # This will delegate you to the wrong main clsas when running in grade mode.
-        for name, cls in inspect.getmembers(importlib.import_module(self.__module__), inspect.isclass):
-            # print("checking", cls)
+        #  for name, cls in inspect.getmembers(importlib.import_module(self.__module__), inspect.isclass):
+        for name, cls in inspect.getmembers(importlib.import_module(good_module_name), inspect.isclass):
             if issubclass(cls, Report):
                 for q,_ in cls.questions:
-                    if q == self.__class__:
+                    if self.__class__.__name__ == q.__name__:
                         found_reports.append(cls)
         if len(found_reports) == 0:
             pass # This case occurs when the report _grade script is being run.
@@ -682,7 +686,14 @@ class UTestCase(unittest.TestCase):
 
     @classmethod
     def _cache_file(cls):
-        return os.path.dirname(inspect.getabsfile(cls)) + "/unitgrade_data/" + cls.__name__ + ".pkl"
+        # This seems required because python can throw an exception that cls is a 'built-in'(??) when it
+        # isn't. I don't know what causes it, but it may be the test system.
+        try:
+            module_name = inspect.getabsfile(cls)
+        except Exception as e:
+            module_name = cls.__module__
+        return os.path.dirname(module_name) + "/unitgrade_data/" + cls.__name__ + ".pkl"
+        # return os.path.dirname(inspect.getabsfile(cls)) + "/unitgrade_data/" + cls.__name__ + ".pkl"
 
     @classmethod
     def _artifact_file_for_setUpClass(cls):
@@ -711,6 +722,8 @@ class UTestCase(unittest.TestCase):
         if self._cache is not None:  # Cache already loaded. We will not load it twice.
             return
             # raise Exception("Loaded cache which was already set. What is going on?!")
+        # str(self.__class__)
+
         cfile = self.__class__._cache_file()
         if os.path.exists(cfile):
             try:
