@@ -53,6 +53,8 @@ class Capturing(list):
     def __enter__(self, capture_errors=True):  # don't put arguments here.
         self._stdout = sys.stdout if self._stdout == None else self._stdout
         self._stringio = StringIO()
+        self._stringio_err = StringIO()
+
         if self.unmute:
             sys.stdout = Logger(self._stringio)
         else:
@@ -60,7 +62,9 @@ class Capturing(list):
 
         if capture_errors:
             self._sterr = sys.stderr
-            sys.sterr = StringIO()  # memory hole it
+            # sys.sterr = StringIO()  # memory hole it
+            sys.sterr = self._stringio_err
+
         self.capture_errors = capture_errors
         return self
 
@@ -70,7 +74,7 @@ class Capturing(list):
         sys.stdout = self._stdout
         if self.capture_errors:
             sys.sterr = self._sterr
-
+            self.errors = self._stringio_err.getvalue()
 
 class Capturing2(Capturing):
     def __exit__(self, *args):
